# About
![Build](https://img.shields.io/github/workflow/status/andrewt110216/iq-tester-game/Tests?style=plastic)

`iqtester` is a simple command-line version of the classic game "IQ Tester"

[PyPI Home Page](https://pypi.org/project/iqtester/)

# Quick Start

## How to Play

IQ Tester is played on a triangular board, typically with 5 rows of holes and pegs.

Start with any one hole empty. As you jump the pegs remove them from the board.

Try to leave only one peg. See how you rate!

## Support Python Versions

Python 3.7+

## Mac / Linux
```
pip install iqtester
```

## Windows
```
py -m pip install iqtester
```

## Start Playing
```
python3 -m iqtester
```